==> haskell-xss-sanitize-0.3.7.2-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-7Qh8CAMJ4cnN9GgJCgrHz
key:                  xss-sanitize-0.3.7.2-7Qh8CAMJ4cnN9GgJCgrHz
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  9ed66d928f4f25415681b23556379402
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-7Qh8CAMJ4cnN9GgJCgrHz
depends:
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    containers-0.6.7 css-text-0.1.3.0-1LmBKFoakOCCsHyYk66Wr8
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    tagsoup-0.14.8-6SzAK0LrK3QBWvkf6keIrz text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.7.2-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-BHyhYiRfn3hElfUAk6qD7w
key:                  xss-sanitize-0.3.7.2-BHyhYiRfn3hElfUAk6qD7w
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  5d6d1417839ce01c7b37869e8d92b621
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-BHyhYiRfn3hElfUAk6qD7w
depends:
    attoparsec-0.14.4-99Ep8AgC5YbKR8GAd3oR9D base-4.17.2.1
    containers-0.6.7 css-text-0.1.3.0-6swNiVJxjP09j9KyrUqVtX
    network-uri-2.6.4.2-FdqTTZWnFNX96ukBHXQ0ED
    tagsoup-0.14.8-3PaODuvzH5i2WfKMjBWtOp text-2.0.2
    utf8-string-1.0.2-6nfZpgw1Ffy3MDnMPT0XX9

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
